# Generated by Django 4.2.2 on 2023-06-08 12:43

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("cms_qe_table", "0001_initial"),
    ]

    operations = [
        migrations.AlterField(
            model_name="tablepluginmodel",
            name="columns",
            field=models.JSONField(default=dict, verbose_name="Columns to show"),
        ),
        migrations.AlterField(
            model_name="tablepluginmodel",
            name="filter",
            field=models.JSONField(default=dict, verbose_name="Filter"),
        ),
    ]
