<iframe src="{{ instance.src }}"{% if instance.allow %} allow{% endif %}{% if instance.allow_full_screen is not None %} allowfullscreen="{% if instance.allow_full_screen %}1{% else %}0{% endif %}"{% endif %}{% if instance.allow_payment_request is not None %} allowpaymentrequest="{% if instance.allow_payment_request %}1{% else %}0{% endif %}"{% endif %}{% if instance.height %} height="{{ instance.height }}"{% endif %}{% if instance.width %} width="{{ instance.width }}"{% endif %}{% if instance.loading %} loading="{{ instance.loading }}"{% endif %}{% if instance.name %} name="{{ instance.name }}"{% endif %}{% if instance.referrer_policy %} referrerpolicy="{{ instance.referrer_policy }}"{% endif %}{% if instance.sandbox %} sandbox="{{ instance.sandbox }}"{% endif %}{% if instance.src_doc %} srcdoc="{{ instance.src_doc }}"{% endif %}{% if instance.attributes %}{% for name, value in instance.attributes.items %} {{ name }}="{{ value }}"{% endfor %}{% endif %}></iframe>
