<script src="{{ instance.src }}"{% if instance.asyncf %} async{% endif %}{% if instance.cross_origin %} crossorigin="{{ instance.cross_origin }}"{% endif %}{% if instance.defer %} defer{% endif %}{% if instance.integrity %} integrity="{{ instance.integrity }}"{% endif %}{% if instance.referrer_policy %} referrerpolicy="{{ instance.referrer_policy }}"{% endif %}{% if instance.nomodule %} nomodule{% endif %}{% if instance.title %} title="{{ instance.title }}"{% endif %}{% if instance.type %} type="{{ instance.type }}"{% endif %}{% if instance.attributes %}{% for name, value in instance.attributes.items %} {{ name }}="{{ value }}"{% endfor %}{% endif %}></script>
