{% load i18n static cms_tags sekizai_tags %}
{# Doctype is important for Django CMS so it can correctly detect height of window. #}
<!DOCTYPE html>
<html lang="{{ LANGUAGE_CODE }}">
    <head>
        <title>{% block title %}{% page_attribute "page_title" %}{% endblock %}</title>
        <link rel="stylesheet" href="{% static "css/example.css" %}">
        {% render_block "css" %}
        {% include 'cms_qe/include/head.html' %}
    </head>
    <body>
        {% include 'cms_qe/include/body_top.html' %}
        {% cms_toolbar %}
        {% block header %}
            <header>
                {% static_placeholder "header" %}
            </header>
        {% endblock %}
        {% block content %}{% endblock %}
        {% block footers %}
            <footer>
                {% static_placeholder "footer" %}
            </footer>
        {% endblock %}
        {% include "cms_qe/include/body_bottom.html" %}
        {% render_block "js" %}
    </body>
</html>
