# Generated by Django 4.2.2 on 2023-06-09 08:48

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("cms_qe_auth", "0003_auto_20210420_1050"),
    ]

    operations = [
        migrations.AlterField(
            model_name="user",
            name="first_name",
            field=models.CharField(
                blank=True, max_length=150, verbose_name="first name"
            ),
        ),
        migrations.AlterField(
            model_name="user",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
            ),
        ),
    ]
