# Generated by Django 4.2.2 on 2023-06-09 09:26

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("cms_qe_auth", "0004_alter_user_first_name_alter_user_id"),
    ]

    operations = [
        migrations.DeleteModel(
            name="Group",
        ),
    ]
