/*
    Fix label-value overlap in change form.
*/
form .flex-container {
    display: flex;
}

form .aligned label + div.readonly {
    margin-top: -0.5em;
}

.aligned label + p, .aligned .checkbox-row + div.help, .aligned label + div.readonly {
    margin-left: 1em;
}
