{% if config.GOOGLE_TAG_MANAGER_ID %}
    <!-- Google tag (gtag.js) -->
    <script async src="https://www.googletagmanager.com/gtag/js?id={{ config.GOOGLE_TAG_MANAGER_ID }}"></script>
    <script>
        window.dataLayer = window.dataLayer || [];
        function gtag() {dataLayer.push(arguments)}
        gtag('js', new Date());
        gtag('config', '{{ config.GOOGLE_TAG_MANAGER_ID }}');
        {{ config.GOOGLE_TAG_MANAGER_SCRIPT|safe }}
    </script>
{% endif %}
