{% extends CMS_TEMPLATE %}
{% load i18n %}

{% block title %}{% translate "Login to Your Account" %}{% endblock %}

{% block content %}
    {% include "cms_qe/auth/login_form_plugin.html" %}
{% endblock %}
