# Generated by Django 4.2.2 on 2023-06-08 11:47

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="TablePluginModel",
            fields=[
                (
                    "cmsplugin_ptr",
                    models.OneToOneField(
                        auto_created=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        parent_link=True,
                        primary_key=True,
                        related_name="%(app_label)s_%(class)s",
                        serialize=False,
                        to="cms.cmsplugin",
                    ),
                ),
                (
                    "table",
                    models.CharField(max_length=100, verbose_name="Table to show"),
                ),
                (
                    "columns",
                    models.JSONField(default="", verbose_name="Columns to show"),
                ),
                ("filter", models.JSONField(default="", verbose_name="Filter")),
                (
                    "paging_show",
                    models.BooleanField(default=True, verbose_name="Show paging"),
                ),
                (
                    "paging_per_page",
                    models.IntegerField(
                        default=20, verbose_name="How many items per page when paging"
                    ),
                ),
            ],
            options={
                "abstract": False,
            },
            bases=("cms.cmsplugin",),
        ),
    ]
