{% load i18n %}
{% block search_form %}
    <form action="{% url "site-search-result" %}" method="get" class="frm frm-search">
        <input type="search" name="q" placeholder="{% translate "Enter your search term" %}" class="input-text input-large" id="id_q" value="{{ request.GET.q }}">
        <input type="submit" value="{% translate "Search" %}">
    </form>
{% endblock %}
