<link href="{{ instance.href }}"{% if instance.rel %} rel="{{ instance.rel }}"{% endif %}{% if instance.cross_origin %} crossorigin="{{ instance.cross_origin }}"{% endif %}{% if instance.hreflang %} hreflang="{{ instance.hreflang }}"{% endif %}{% if instance.media %} media="{{ instance.media }}"{% endif %}{% if instance.referrer_policy %} referrerpolicy="{{ instance.referrer_policy }}"{% endif %}{% if instance.sizes %} sizes="{{ instance.sizes }}"{% endif %}{% if instance.title %} title="{{ instance.title }}"{% endif %}{% if instance.type %} type="{{ instance.type }}"{% endif %}{% if instance.attributes %}{% for name, value in instance.attributes.items %} {{ name }}="{{ value }}"{% endfor %}{% endif %}>
