{% load i18n %}

{% if request.user.is_authenticated %}
    {% if request.user.get_full_name %}
        {{ request.user.get_full_name }}
    {% else %}
        {{ request.user.email }}
    {% endif %}
    | <a href="{% url 'logout' %}">{% translate "Logout" %}</a>
{% else %}
    <a href="{% url 'login' %}">{% translate "Login" %}</a>
{% endif %}
