{% extends "aldryn_search/base.html" %}
{% block content_search %}
    <div class="search-results">
        <ul>
            {% include "aldryn_search/includes/search_items.html" %}
        </ul>
    </div>
    {% include "aldryn_search/includes/pagination.html" with obj_string=_('results') %}
{% endblock %}
