{% extends CMS_TEMPLATE %}
{% load i18n %}

{% block title %}{% translate "Login is locked" %}{% endblock %}

{% block content %}
    <ul class="messagelist">
        <li class="error">{% blocktrans %}Too many attempts to log in. Please try again later.{% endblocktrans %}</li>
    </ul>
{% endblock %}
